@@ -1,8 +1,3 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from six import python_2_unicode_compatible, string_types
-import warnings
-
 from canvasapi.calendar_event import CalendarEvent
 from canvasapi.canvas_object import CanvasObject
 from canvasapi.communication_channel import CommunicationChannel
@@ -15,7 +10,6 @@ from canvasapi.usage_rights import UsageRights
 from canvasapi.util import combine_kwargs, obj_or_id, obj_or_str
 
 
-@python_2_unicode_compatible
 class User(CanvasObject):
     def __str__(self):
         return "{} ({})".format(self.name, self.id)
@@ -87,7 +81,7 @@ class User(CanvasObject):
 
         if isinstance(migration_type, Migrator):
             kwargs["migration_type"] = migration_type.type
-        elif isinstance(migration_type, string_types):
+        elif isinstance(migration_type, str):
             kwargs["migration_type"] = migration_type
         else:
             raise TypeError("Parameter migration_type must be of type Migrator or str")
@@ -739,142 +733,6 @@ class User(CanvasObject):
             _kwargs=combine_kwargs(**kwargs),
         )
 
-    def list_calendar_events_for_user(self, **kwargs):
-        """
-        List calendar events that the current user can view or manage.
-
-        .. warning::
-            .. deprecated:: 0.10.0
-                Use :func:`canvasapi.user.User.get_calendar_events_for_user` instead.
-
-        :calls: `GET /api/v1/users/:user_id/calendar_events \
-        <https://canvas.instructure.com/doc/api/calendar_events.html#method.calendar_events_api.user_index>`_
-
-        :rtype: :class:`canvasapi.paginated_list.PaginatedList` of
-            :class:`canvasapi.calendar_event.CalendarEvent`
-        """
-        warnings.warn(
-            "`list_calendar_events_for_user`"
-            " is being deprecated and will be removed in a future version."
-            " Use `get_calendar_events_for_user` instead",
-            DeprecationWarning,
-        )
-
-        return self.get_calendar_events_for_user(**kwargs)
-
-    def list_communication_channels(self, **kwargs):
-        """
-        List communication channels for the specified user, sorted by
-        position.
-
-        .. warning::
-            .. deprecated:: 0.10.0
-                Use :func:`canvasapi.user.User.get_communication_channels` instead.
-
-        :calls: `GET /api/v1/users/:user_id/communication_channels \
-        <https://canvas.instructure.com/doc/api/communication_channels.html#method.communication_channels.index>`_
-
-        :rtype: :class:`canvasapi.paginated_list.PaginatedList` of
-            :class:`canvasapi.communication_channel.CommunicationChannel`
-        """
-        warnings.warn(
-            "`list_communication_channels`"
-            " is being deprecated and will be removed in a future version."
-            " Use `get_communication_channels` instead",
-            DeprecationWarning,
-        )
-
-        return self.get_communication_channels(**kwargs)
-
-    def list_files(self, **kwargs):
-        """
-        Returns the paginated list of files for the user.
-
-        .. warning::
-            .. deprecated:: 0.10.0
-                Use :func:`canvasapi.user.User.get_files` instead.
-
-        :calls: `GET /api/v1/users/:user_id/files \
-            <https://canvas.instructure.com/doc/api/files.html#method.files.api_index>`_
-
-        :rtype: :class:`canvasapi.paginated_list.PaginatedList` of
-            :class:`canvasapi.file.File`
-        """
-        warnings.warn(
-            "`list_files` is being deprecated and will be removed in a future "
-            "version. Use `get_files` instead",
-            DeprecationWarning,
-        )
-
-        return self.get_files(**kwargs)
-
-    def list_folders(self, **kwargs):
-        """
-        Returns the paginated list of all folders for the given user. This will be returned as a
-        flat list containing all subfolders as well.
-
-        .. warning::
-            .. deprecated:: 0.10.0
-                Use :func:`canvasapi.user.User.get_folders` instead.
-
-        :calls: `GET /api/v1/users/:user_id/folders \
-        <https://canvas.instructure.com/doc/api/files.html#method.folders.list_all_folders>`_
-
-        :rtype: :class:`canvasapi.paginated_list.PaginatedList` of
-            :class:`canvasapi.folder.Folder`
-        """
-        warnings.warn(
-            "`list_folders` is being deprecated and will be removed in a "
-            "future version. Use `get_folders` instead.",
-            DeprecationWarning,
-        )
-
-        return self.get_folders(**kwargs)
-
-    def list_observees(self, **kwargs):
-        """
-        List the users that the given user is observing
-
-        .. warning::
-            .. deprecated:: 0.10.0
-                Use :func:`canvasapi.user.User.get_observees` instead.
-
-        :calls:  `GET /api/v1/users/:user_id/observees \
-        <https://canvas.instructure.com/doc/api/user_observees.html#method.user_observees.index>`_
-
-        :rtype: :class:`canvasapi.paginated_list.PaginatedList` of
-            :class:`canvasapi.user.User`
-        """
-        warnings.warn(
-            "`list_observees` is being deprecated and will be removed in a "
-            "future version. Use `get_observees` instead",
-            DeprecationWarning,
-        )
-
-        return self.get_observees(**kwargs)
-
-    def list_user_logins(self, **kwargs):
-        """
-        Given a user ID, return that user's logins for the given account.
-
-        .. warning::
-            .. deprecated:: 0.10.0
-                Use :func:`canvasapi.user.User.get_user_logins` instead.
-
-        :calls: `GET /api/v1/users/:user_id/logins \
-        <https://canvas.instructure.com/doc/api/logins.html#method.pseudonyms.index>`_
-
-        :rtype: :class:`canvasapi.paginated_list.PaginatedList` of
-            :class:`canvasapi.login.Login`
-        """
-        warnings.warn(
-            "`list_user_logins` is being deprecated and will be removed in a future version."
-            " Use `get_user_logins` instead",
-            DeprecationWarning,
-        )
-
-        return self.get_user_logins(**kwargs)
-
     def merge_into(self, destination_user):
         """
         Merge this user into another user.
@@ -1024,7 +882,6 @@ class User(CanvasObject):
         ).start()
 
 
-@python_2_unicode_compatible
 class UserDisplay(CanvasObject):
     def __str__(self):
         return "{}".format(self.display_name)
